@@ -20,7 +20,6 @@ class BroadcastThread(Thread):
         self.cameraoutput = cameraoutput
 
     def run(self):
-
         while True:
             buf = self.cameraoutput.nal_queue.get()
             if buf:
@@ -35,14 +34,6 @@ class GSPeerConnectionBroadcaster:
         video_trackList.append(video_track)
         return video_track
 
-    def force_codec(self, pc, sender, forced_codec):
-        kind = forced_codec.split("/")[0]
-        codecs = RTCRtpSender.getCapabilities(kind).codecs
-        transceiver = next(t for t in pc.getTransceivers() if t.sender == sender)
-        transceiver.setCodecPreferences(
-            [codec for codec in codecs if codec.mimeType == forced_codec]
-        )
-
     @classmethod
     async def create(cls, gsdbs):
         self = GSPeerConnectionBroadcaster()
@@ -53,9 +44,12 @@ class GSPeerConnectionBroadcaster:
             if self.gsdbs.credentials["stunenable"]:
                 self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
             if self.gsdbs.credentials["turnenable"]:
-                self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
-                                                self.gsdbs.credentials["turnuser"],
-                                                self.gsdbs.credentials["turnpw"]))
+                self.rtconfiList.append(RTCIceServer(urls=self.gsdbs.credentials["turnserver"],
+                                                     username=self.gsdbs.credentials["turnuser"],
+                                                     credential=self.gsdbs.credentials["turnpw"],
+                                                     credentialType="pw"
+                                                     ))
+
             camera.resolution = (self.gsdbs.credentials["hres"], self.gsdbs.credentials["vres"])
             camera.framerate = self.gsdbs.credentials["framerate"]
             sleep(1)  # camera warm-up time
@@ -104,7 +98,6 @@ class GSPeerConnectionBroadcaster:
 
                 self.peerConnections[id] = pc
 
-
                 video = self.getPiH264Relay()
 
                 @pc.on("iceconnectionstatechange")
